diff --git a/.gitignore b/.gitignore
index a26d102ee..e9b3517bc 100644
--- a/.gitignore
+++ b/.gitignore
@@ -14,10 +14,10 @@ test.php
/.idea/
/app/libraries/*
/app/resources/tmp/*
-/newznab/config/settings.php
-/newznab/config/ircscraper_settings.php
-/newznab/config/ircscraper.php
-/newznab/config/opensssl.php
+/nntmux/config/settings.php
+/nntmux/config/ircscraper_settings.php
+/nntmux/config/ircscraper.php
+/nntmux/config/opensssl.php
/libraries/*
/nbproject/
diff --git a/Changelog b/Changelog
index 8ab071cc9..ae23ddf87 100755
--- a/Changelog
+++ b/Changelog
@@ -1,4 +1,6 @@
2016-06-25 DariusIII
+ * Upd: Update composer.lock
+ * Chg: Switch namespace from newznab to nntmux, rename nntmux script to tmux
* Upd: Update lithium connections
* Upd: Composer will prefer source now on install
2016-06-24 DariusIII
diff --git a/app/config/bootstrap/connections.php b/app/config/bootstrap/connections.php
index 575f7ef1e..62469bb27 100644
--- a/app/config/bootstrap/connections.php
+++ b/app/config/bootstrap/connections.php
@@ -74,7 +74,7 @@ use lithium\data\Connections;
// ));
$config1 = LITHIUM_APP_PATH . DS . 'config' . DS . 'db-config.php';
-$config2 = NN_ROOT . 'newznab' . DS . 'config' . DS . 'config.php';
+$config2 = NN_ROOT . 'nntmux' . DS . 'config' . DS . 'config.php';
$config = file_exists($config1) ? $config1 : $config2;
if (file_exists($config)) {
diff --git a/app/extensions/command/Update.php b/app/extensions/command/Update.php
index 81f468ae0..878da4fe4 100644
--- a/app/extensions/command/Update.php
+++ b/app/extensions/command/Update.php
@@ -23,7 +23,7 @@ use \Smarty;
use \app\extensions\util\Git;
use \app\extensions\util\Versions;
use \lithium\console\command\Help;
-use \newznab\db\DbUpdate;
+use \nntmux\db\DbUpdate;
/**
diff --git a/build/NewPatches.php b/build/NewPatches.php
index 2ca5dbcd3..54adcc671 100644
--- a/build/NewPatches.php
+++ b/build/NewPatches.php
@@ -21,9 +21,9 @@
require_once dirname(__DIR__) . DIRECTORY_SEPARATOR . 'indexer.php';
-use newznab\db\DbUpdate;
-use newznab\utility\Git;
-use newznab\utility\Utility;
+use nntmux\db\DbUpdate;
+use nntmux\utility\Git;
+use nntmux\utility\Utility;
if (!Utility::isCLI()) {
exit;
diff --git a/build/git-hooks/runHooks.php b/build/git-hooks/runHooks.php
index 324cf7b87..961df6b2c 100755
--- a/build/git-hooks/runHooks.php
+++ b/build/git-hooks/runHooks.php
@@ -22,16 +22,16 @@ define('GIT_PRE_COMMIT', true);
require_once realpath(dirname(dirname(__DIR__)) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\DbUpdate;
-use newznab\utility\Git;
-use newznab\utility\Versions;
+use nntmux\db\DbUpdate;
+use nntmux\utility\Git;
+use nntmux\utility\Versions;
echo "Running pre-commit hooks\n";
$error = false;
// TODO Add code here to check permissions on staged files.
-//$files = file(NN_ROOT . 'newznab/build/git-hooks'), FILE_IGNORE_NEW_LINES);
+//$files = file(NN_ROOT . 'nntmux/build/git-hooks'), FILE_IGNORE_NEW_LINES);
//foreach ($files as $file) {
// echo "Filename: $file\n";
//}
diff --git a/build/nntmux.xml b/build/nntmux.xml
index fc104aa45..530954298 100755
--- a/build/nntmux.xml
+++ b/build/nntmux.xml
@@ -8,7 +8,7 @@
9
- 5325
+ 5326
0000-00-00
diff --git a/cli/data/populate_anidb.php b/cli/data/populate_anidb.php
index 6bba40218..681c8d832 100755
--- a/cli/data/populate_anidb.php
+++ b/cli/data/populate_anidb.php
@@ -1,11 +1,11 @@
register();
?>
\ No newline at end of file
diff --git a/libs/pixelead0/Tmdb/Data/Episode.php b/libs/pixelead0/Tmdb/Data/Episode.php
index cdb202727..fc9033d0f 100644
--- a/libs/pixelead0/Tmdb/Data/Episode.php
+++ b/libs/pixelead0/Tmdb/Data/Episode.php
@@ -147,7 +147,7 @@ class Episode{
* Reload the content of this class.
* Could be used to update or complete the information.
*
- * @param \newznab\libraries\TmdbAPI $tmdb An instance of the API handler, necesary to make the API call.
+ * @param \nntmux\libraries\TmdbAPI $tmdb An instance of the API handler, necesary to make the API call.
*/
public function reload($tmdb) {
$tmdb->getEpisode($this->getTVShowID(), $this->getSeasonNumber(), $this->getEpisodeNumber());
diff --git a/libs/pixelead0/Tmdb/Data/Season.php b/libs/pixelead0/Tmdb/Data/Season.php
index 7857ffc3e..36da5dfb3 100644
--- a/libs/pixelead0/Tmdb/Data/Season.php
+++ b/libs/pixelead0/Tmdb/Data/Season.php
@@ -147,7 +147,7 @@ class Season{
* Reload the content of this class.
* Could be used to update or complete the information.
*
- * @param \newznab\libraries\Tmdb $tmdb An instance of the API handler, necesary to make the API call.
+ * @param \nntmux\libraries\Tmdb $tmdb An instance of the API handler, necesary to make the API call.
*/
public function reload($tmdb) {
$tmdb->getSeason($this->getTVShowID(), $this->getSeasonNumber());
diff --git a/misc/IRCScraper/scrape.php b/misc/IRCScraper/scrape.php
index 1c5d56d8f..7f8304c52 100644
--- a/misc/IRCScraper/scrape.php
+++ b/misc/IRCScraper/scrape.php
@@ -1,7 +1,7 @@
$pdo]);
diff --git a/misc/testing/DB/populate_nzb_guid.php b/misc/testing/DB/populate_nzb_guid.php
index 6f01de719..0b4010ee7 100644
--- a/misc/testing/DB/populate_nzb_guid.php
+++ b/misc/testing/DB/populate_nzb_guid.php
@@ -1,13 +1,13 @@
true, 'Settings' => $pdo]);
diff --git a/misc/testing/PostProc/check_previews.php b/misc/testing/PostProc/check_previews.php
index 8f28a3e2d..aa141c946 100644
--- a/misc/testing/PostProc/check_previews.php
+++ b/misc/testing/PostProc/check_previews.php
@@ -4,12 +4,12 @@
// --------------------------------------------------------------
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\Settings;
-use newznab\utility\Utility;
-use newznab\Releases;
-use newznab\NZB;
-use newznab\ReleaseImage;
-use newznab\ConsoleTools;
+use nntmux\db\Settings;
+use nntmux\utility\Utility;
+use nntmux\Releases;
+use nntmux\NZB;
+use nntmux\ReleaseImage;
+use nntmux\ConsoleTools;
$pdo = new Settings();
diff --git a/misc/testing/PostProc/getConsole.php b/misc/testing/PostProc/getConsole.php
index 7308086b1..3ff893314 100644
--- a/misc/testing/PostProc/getConsole.php
+++ b/misc/testing/PostProc/getConsole.php
@@ -3,9 +3,9 @@
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\Category;
-use newznab\db\Settings;
-use newznab\Console;
+use nntmux\Category;
+use nntmux\db\Settings;
+use nntmux\Console;
diff --git a/misc/testing/PostProc/getGameCovers.php b/misc/testing/PostProc/getGameCovers.php
index 5ab229e5f..6a99d76bb 100644
--- a/misc/testing/PostProc/getGameCovers.php
+++ b/misc/testing/PostProc/getGameCovers.php
@@ -3,8 +3,8 @@
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\Settings;
-use newznab\Games;
+use nntmux\db\Settings;
+use nntmux\Games;
$pdo = new Settings();
diff --git a/misc/testing/PostProc/getImdb.php b/misc/testing/PostProc/getImdb.php
index d531ae680..06970ae47 100644
--- a/misc/testing/PostProc/getImdb.php
+++ b/misc/testing/PostProc/getImdb.php
@@ -2,9 +2,9 @@
//This script will update all records in the movieinfo table
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\Settings;
-use newznab\ColorCLI;
-use newznab\Movie;
+use nntmux\db\Settings;
+use nntmux\ColorCLI;
+use nntmux\Movie;
$pdo = new Settings();
$c = new ColorCLI();
diff --git a/misc/testing/PostProc/getMovieCovers.php b/misc/testing/PostProc/getMovieCovers.php
index 0cb67aa82..27082f40f 100644
--- a/misc/testing/PostProc/getMovieCovers.php
+++ b/misc/testing/PostProc/getMovieCovers.php
@@ -2,8 +2,8 @@
//This script will update all records in the movieinfo table where there is no cover
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\Settings;
-use newznab\Movie;
+use nntmux\db\Settings;
+use nntmux\Movie;
$pdo = new Settings();
diff --git a/misc/testing/PostProc/getXXXCovers.php b/misc/testing/PostProc/getXXXCovers.php
index 101af3646..0a8a86d13 100644
--- a/misc/testing/PostProc/getXXXCovers.php
+++ b/misc/testing/PostProc/getXXXCovers.php
@@ -2,9 +2,9 @@
//This script will update all records in the xxxinfo table where there is no cover
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\Settings;
-use newznab\XXX;
-use newznab\ColorCLI;
+use nntmux\db\Settings;
+use nntmux\XXX;
+use nntmux\ColorCLI;
$pdo = new Settings();
diff --git a/misc/testing/PostProc/updateBookImages.php b/misc/testing/PostProc/updateBookImages.php
index b4f51d8c5..c6afc1efc 100644
--- a/misc/testing/PostProc/updateBookImages.php
+++ b/misc/testing/PostProc/updateBookImages.php
@@ -1,7 +1,7 @@
getSetting('giantbombkey');
$cli = new ColorCLI();
diff --git a/misc/testing/Tests/test_nntp_server.php b/misc/testing/Tests/test_nntp_server.php
index 2505e757c..2806d7adc 100755
--- a/misc/testing/Tests/test_nntp_server.php
+++ b/misc/testing/Tests/test_nntp_server.php
@@ -2,9 +2,9 @@
// To troubleshoot what's actually on usenet.
require_once realpath(dirname(dirname(dirname(__DIR__))) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\Binaries;
-use newznab\ColorCLI;
-use newznab\NNTP;
+use nntmux\Binaries;
+use nntmux\ColorCLI;
+use nntmux\NNTP;
$cli = new ColorCLI();
diff --git a/misc/testing/Tests/test_regex.php b/misc/testing/Tests/test_regex.php
index df3b90520..2677a83a8 100644
--- a/misc/testing/Tests/test_regex.php
+++ b/misc/testing/Tests/test_regex.php
@@ -1,13 +1,13 @@
queryDirect("select releases.searchname, releases.postdate, uncompress(release_nfos.nfo) as nfo from releases inner join release_nfos on releases.ID = release_nfos.releaseID and release_nfos.nfo is not null order by postdate");
while ($row = $db->getAssocArray($res))
{
$dir = date("Ymd", strtotime($row["postdate"]));
if (!file_exists($dir))
mkdir($dir);
$filename = $dir."/".safeFilename($row["searchname"]).".nfo";
if (!file_exists($filename))
{
$fh = fopen($filename, 'w');
fwrite($fh, Utility::cp437toUTF($row["nfo"]));
fclose($fh);
}
}
\ No newline at end of file
+queryDirect("select releases.searchname, releases.postdate, uncompress(release_nfos.nfo) as nfo from releases inner join release_nfos on releases.ID = release_nfos.releaseID and release_nfos.nfo is not null order by postdate");
while ($row = $db->getAssocArray($res))
{
$dir = date("Ymd", strtotime($row["postdate"]));
if (!file_exists($dir))
mkdir($dir);
$filename = $dir."/".safeFilename($row["searchname"]).".nfo";
if (!file_exists($filename))
{
$fh = fopen($filename, 'w');
fwrite($fh, Utility::cp437toUTF($row["nfo"]));
fclose($fh);
}
}
\ No newline at end of file
diff --git a/misc/testing/fix_filesize.php b/misc/testing/fix_filesize.php
index b788cba89..ee0ae54d9 100644
--- a/misc/testing/fix_filesize.php
+++ b/misc/testing/fix_filesize.php
@@ -8,8 +8,8 @@ Author: lordgnu
require_once realpath(dirname(dirname(__DIR__)) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\db\Settings;
-use newznab\NZB;
+use nntmux\db\Settings;
+use nntmux\NZB;
$pdo = new Settings;
$nzb = new NZB;
diff --git a/misc/testing/nzb-export.php b/misc/testing/nzb-export.php
index 03fab1a35..5d3f511f0 100644
--- a/misc/testing/nzb-export.php
+++ b/misc/testing/nzb-export.php
@@ -1,7 +1,7 @@
true, 'Settings' => $pdo]);
diff --git a/misc/testing/rottentom.php b/misc/testing/rottentom.php
index 655b3c15b..3aed1771c 100644
--- a/misc/testing/rottentom.php
+++ b/misc/testing/rottentom.php
@@ -1,8 +1,8 @@
getSetting('rottentomatokey');
diff --git a/misc/testing/tidynzbfolder.php b/misc/testing/tidynzbfolder.php
index f6fb32eae..d59908b0a 100644
--- a/misc/testing/tidynzbfolder.php
+++ b/misc/testing/tidynzbfolder.php
@@ -1,8 +1,8 @@
(string): python|php
// The type of process we want to do: $options[1] => (string): releases
@@ -313,7 +313,7 @@ function charCheck($char)
/**
* Check if the group should be processed.
*
- * @param \newznab\db\Settings $pdo
+ * @param \nntmux\db\Settings $pdo
* @param int $groupID
*/
function collectionCheck(&$pdo, $groupID)
@@ -326,7 +326,7 @@ function collectionCheck(&$pdo, $groupID)
/**
* Connect to usenet, return NNTP object.
*
- * @param \newznab\db\Settings $pdo
+ * @param \nntmux\db\Settings $pdo
* @param bool $alternate Use alternate NNTP provider.
*
* @return NNTP
diff --git a/misc/update/nix/multiprocessing/backfill.php b/misc/update/nix/multiprocessing/backfill.php
index 8e42089f6..50845fbd9 100644
--- a/misc/update/nix/multiprocessing/backfill.php
+++ b/misc/update/nix/multiprocessing/backfill.php
@@ -1,7 +1,7 @@
processWorkType(
'backfill', (isset($argv[1]) && is_numeric($argv[1]) && $argv[1] > 0 ? array(0 => $argv[1]) : array(0 => false))
diff --git a/misc/update/nix/multiprocessing/binaries.php b/misc/update/nix/multiprocessing/binaries.php
index f02ee7c6a..563bdcdd4 100644
--- a/misc/update/nix/multiprocessing/binaries.php
+++ b/misc/update/nix/multiprocessing/binaries.php
@@ -6,5 +6,5 @@ if (!isset($argv[1]) || !is_numeric($argv[1])) {
}
declare(ticks=1);
require('.do_not_run/require.php');
-use newznab\libraries\Forking;
+use nntmux\libraries\Forking;
(new Forking())->processWorkType('binaries', array(0 => $argv[1]));
\ No newline at end of file
diff --git a/misc/update/nix/multiprocessing/fixrelnames.php b/misc/update/nix/multiprocessing/fixrelnames.php
index 0b014f6e9..d77799b4b 100644
--- a/misc/update/nix/multiprocessing/fixrelnames.php
+++ b/misc/update/nix/multiprocessing/fixrelnames.php
@@ -9,7 +9,7 @@ if (!isset($argv[1]) || !in_array($argv[1], ['standard', 'predbft'])) {
require('.do_not_run/require.php');
-use newznab\libraries\Forking;
+use nntmux\libraries\Forking;
declare(ticks = 1);
diff --git a/misc/update/nix/multiprocessing/import.php b/misc/update/nix/multiprocessing/import.php
index c7ee70c60..814ee9dd6 100644
--- a/misc/update/nix/multiprocessing/import.php
+++ b/misc/update/nix/multiprocessing/import.php
@@ -2,7 +2,7 @@
declare(ticks=1);
require('.do_not_run/require.php');
-use newznab\libraries\ForkingImportNZB;
+use nntmux\libraries\ForkingImportNZB;
if (!isset($argv[1]) || !is_dir($argv[1])) {
exit(
diff --git a/misc/update/nix/multiprocessing/postprocess.php b/misc/update/nix/multiprocessing/postprocess.php
index f9b8a0039..63c2df5e9 100644
--- a/misc/update/nix/multiprocessing/postprocess.php
+++ b/misc/update/nix/multiprocessing/postprocess.php
@@ -16,6 +16,6 @@ if (!isset($argv[1]) || !in_array($argv[1], ['ama', 'add', 'mov', 'nfo', 'sha',
declare(ticks=1);
require('.do_not_run/require.php');
-use newznab\libraries\Forking;
+use nntmux\libraries\Forking;
(new Forking())->processWorkType('postProcess_' . $argv[1], (isset($argv[2]) && $argv[2] === 'true' ? [0 => true] : []));
\ No newline at end of file
diff --git a/misc/update/nix/multiprocessing/releases.php b/misc/update/nix/multiprocessing/releases.php
index b3eb9964e..fbd68c7f1 100644
--- a/misc/update/nix/multiprocessing/releases.php
+++ b/misc/update/nix/multiprocessing/releases.php
@@ -2,6 +2,6 @@
declare(ticks=1);
require('.do_not_run/require.php');
-use newznab\libraries\Forking;
+use nntmux\libraries\Forking;
(new Forking())->processWorkType('releases');
\ No newline at end of file
diff --git a/misc/update/nix/multiprocessing/requestid.php b/misc/update/nix/multiprocessing/requestid.php
index 9de63e411..a70c72787 100644
--- a/misc/update/nix/multiprocessing/requestid.php
+++ b/misc/update/nix/multiprocessing/requestid.php
@@ -2,6 +2,6 @@
declare(ticks=1);
require('.do_not_run/require.php');
-use \newznab\libraries\Forking;
+use \nntmux\libraries\Forking;
(new Forking())->processWorkType('request_id');
\ No newline at end of file
diff --git a/misc/update/nix/multiprocessing/safe.php b/misc/update/nix/multiprocessing/safe.php
index a7f7c6601..f8d3783e4 100644
--- a/misc/update/nix/multiprocessing/safe.php
+++ b/misc/update/nix/multiprocessing/safe.php
@@ -10,6 +10,6 @@ if (!isset($argv[1]) || !in_array($argv[1], ['backfill', 'binaries'])) {
declare(ticks=1);
require('.do_not_run/require.php');
-use \newznab\libraries\Forking;
+use \nntmux\libraries\Forking;
(new Forking())->processWorkType('safe_' . $argv[1]);
diff --git a/misc/update/nix/multiprocessing/update_per_group.php b/misc/update/nix/multiprocessing/update_per_group.php
index 316b2773a..46f431434 100644
--- a/misc/update/nix/multiprocessing/update_per_group.php
+++ b/misc/update/nix/multiprocessing/update_per_group.php
@@ -2,7 +2,7 @@
declare(ticks=1);
require('.do_not_run/require.php');
-use \newznab\libraries\Forking;
+use \nntmux\libraries\Forking;
// This is the same as the python update_threaded.php
(new Forking())->processWorkType('update_per_group');
\ No newline at end of file
diff --git a/misc/update/nix/tmux/bin/fixreleasenames.php b/misc/update/nix/tmux/bin/fixreleasenames.php
index 8df6986e0..968ad9eab 100644
--- a/misc/update/nix/tmux/bin/fixreleasenames.php
+++ b/misc/update/nix/tmux/bin/fixreleasenames.php
@@ -1,13 +1,13 @@
true]))->checkPre((isset($argv[1]) && is_numeric($argv[1]) ? $argv[1] : false));
diff --git a/misc/update/nix/tmux/bin/postprocess_threaded.php b/misc/update/nix/tmux/bin/postprocess_threaded.php
index e74fa49df..75c75e72f 100644
--- a/misc/update/nix/tmux/bin/postprocess_threaded.php
+++ b/misc/update/nix/tmux/bin/postprocess_threaded.php
@@ -1,10 +1,10 @@
stopIfRunning();
diff --git a/misc/update/nntpproxy.php b/misc/update/nntpproxy.php
index 18c7b42b1..1c1699220 100644
--- a/misc/update/nntpproxy.php
+++ b/misc/update/nntpproxy.php
@@ -1,8 +1,8 @@
true]);
$m->updateUpcoming();
diff --git a/newznab/ADE.php b/nntmux/ADE.php
similarity index 99%
rename from newznab/ADE.php
rename to nntmux/ADE.php
index 6ec14a1f4..8e1205f5f 100644
--- a/newznab/ADE.php
+++ b/nntmux/ADE.php
@@ -1,7 +1,7 @@
pdo->log->doEcho($this->pdo->log->primary($dMessage));
}
} else {
- $dMessage = "No groups specified. Ensure groups are added to newznab's database for updating.";
+ $dMessage = "No groups specified. Ensure groups are added to nntmux's database for updating.";
if ($this->_debug) {
$this->_debugging->log(get_class(), __FUNCTION__, $dMessage, Logger::LOG_FATAL);
}
diff --git a/newznab/Binaries.php b/nntmux/Binaries.php
similarity index 99%
rename from newznab/Binaries.php
rename to nntmux/Binaries.php
index b2b30a53b..271e8eff8 100644
--- a/newznab/Binaries.php
+++ b/nntmux/Binaries.php
@@ -1,7 +1,7 @@
log(
- 'No groups specified. Ensure groups are added to newznab\'s database for updating.',
+ 'No groups specified. Ensure groups are added to nntmux\'s database for updating.',
__FUNCTION__,
Logger::LOG_NOTICE,
'warning'
diff --git a/newznab/Books.php b/nntmux/Books.php
similarity index 99%
rename from newznab/Books.php
rename to nntmux/Books.php
index 924185169..e0f5228ec 100644
--- a/newznab/Books.php
+++ b/nntmux/Books.php
@@ -1,7 +1,7 @@
';
* @param $extra string Extra, separated by \r\n
- * ie.: $extra = 'Organization: \r\nNNTP-Posting-Host: <127.0.0.1>';
+ * ie.: $extra = 'Organization: \r\nNNTP-Posting-Host: <127.0.0.1>';
* @param $yEnc bool Encode the message with yEnc?
* @param $compress bool Compress the message with GZip?
*
diff --git a/newznab/NZB.php b/nntmux/NZB.php
similarity index 98%
rename from newznab/NZB.php
rename to nntmux/NZB.php
index c0dedfe2c..d6eb5c581 100644
--- a/newznab/NZB.php
+++ b/nntmux/NZB.php
@@ -1,7 +1,7 @@
NNTP ; Class NNTP.
* 'Nfo' => Nfo ; Class Nfo.
* 'NZB' => NZB ; Class NZB.
- * 'Settings' => DB ; Class newznab\db\Settings.
+ * 'Settings' => DB ; Class nntmux\db\Settings.
* 'PostProcess' => PostProcess ; Class PostProcess.
* )
*
diff --git a/newznab/NZBExport.php b/nntmux/NZBExport.php
similarity index 98%
rename from newznab/NZBExport.php
rename to nntmux/NZBExport.php
index 8f8886b93..6a2cd087b 100644
--- a/newznab/NZBExport.php
+++ b/nntmux/NZBExport.php
@@ -1,8 +1,8 @@
\n\n";
}
- $nzb .= "\n";
+ $nzb .= "\n";
return $nzb;
}
diff --git a/newznab/NZBVortex.php b/nntmux/NZBVortex.php
similarity index 99%
rename from newznab/NZBVortex.php
rename to nntmux/NZBVortex.php
index 7579a0d76..78cc0a8b9 100644
--- a/newznab/NZBVortex.php
+++ b/nntmux/NZBVortex.php
@@ -1,5 +1,5 @@
.
* @author niel
*/
-namespace newznab;
+namespace nntmux;
use Closure;
diff --git a/newznab/Popporn.php b/nntmux/Popporn.php
similarity index 99%
rename from newznab/Popporn.php
rename to nntmux/Popporn.php
index 783516875..803662fd0 100644
--- a/newznab/Popporn.php
+++ b/nntmux/Popporn.php
@@ -1,7 +1,7 @@
Release GUID(mandatory), 'id' => ReleaseID(optional, pass false)]
- * @param \newznab\db\Settings $pdo
+ * @param \nntmux\db\Settings $pdo
*/
public function deleteRelease($identifiers, Settings $pdo)
{
@@ -100,7 +100,7 @@ class SphinxSearch
* Update Sphinx Relases index for given releaseid.
*
* @param int $releaseID
- * @param \newznab\db\Settings $pdo
+ * @param \nntmux\db\Settings $pdo
*/
public function updateRelease($releaseID, Settings $pdo)
{
diff --git a/newznab/SpotNab.php b/nntmux/SpotNab.php
similarity index 99%
rename from newznab/SpotNab.php
rename to nntmux/SpotNab.php
index 7c6e0180c..e0c88ed72 100644
--- a/newznab/SpotNab.php
+++ b/nntmux/SpotNab.php
@@ -1,8 +1,8 @@
.
* @author niel
*/
-namespace newznab\data;
+namespace nntmux\data;
/**
* This is the base class for a data abstraction layer.
diff --git a/newznab/data/model/Anidb.php b/nntmux/data/model/Anidb.php
similarity index 93%
rename from newznab/data/model/Anidb.php
rename to nntmux/data/model/Anidb.php
index 93d429632..f8258d6c9 100644
--- a/newznab/data/model/Anidb.php
+++ b/nntmux/data/model/Anidb.php
@@ -18,9 +18,9 @@
* @author niel
* @copyright 2014 nZEDb
*/
-namespace newznab\data\model;
+namespace nntmux\data\model;
-use newznab\data\Model;
+use nntmux\data\Model;
class Anidb extends Model
{
diff --git a/newznab/data/source/Database.php b/nntmux/data/source/Database.php
similarity index 99%
rename from newznab/data/source/Database.php
rename to nntmux/data/source/Database.php
index 42b9d211a..2fd9aa8b7 100644
--- a/newznab/data/source/Database.php
+++ b/nntmux/data/source/Database.php
@@ -17,15 +17,15 @@
* @link .
* @author niel
*/
-namespace newznab\data\model\source;
+namespace nntmux\data\model\source;
use \PDO;
use \PDOException;
use \InvalidArgumentException;
use \UnexpectedValueException;
-use newznab\data\Source;
-use newznab\NetworkException;
+use nntmux\data\Source;
+use nntmux\NetworkException;
/**
* The `Database` class provides the base-level abstraction for SQL-oriented relational databases.
diff --git a/newznab/data/source/Result.php b/nntmux/data/source/Result.php
similarity index 98%
rename from newznab/data/source/Result.php
rename to nntmux/data/source/Result.php
index 978cabc32..9d5eb7bd9 100644
--- a/newznab/data/source/Result.php
+++ b/nntmux/data/source/Result.php
@@ -17,9 +17,9 @@
* @link .
* @author niel
*/
-namespace newznab\data\model\source;
+namespace nntmux\data\model\source;
-use newznab\Object;
+use nntmux\Object;
abstract class Result extends Object implements \Iterator
{
diff --git a/newznab/data/source/database/MySQL.php b/nntmux/data/source/database/MySQL.php
similarity index 99%
rename from newznab/data/source/database/MySQL.php
rename to nntmux/data/source/database/MySQL.php
index 34ba7760c..75975d178 100644
--- a/newznab/data/source/database/MySQL.php
+++ b/nntmux/data/source/database/MySQL.php
@@ -17,12 +17,12 @@
* @link .
* @author niel
*/
-namespace newznab\data\model\source\database;
+namespace nntmux\data\model\source\database;
use \PDO;
use \PDOException;
-use newznab\data\model\source\Database;
+use nntmux\data\model\source\Database;
/**
* Extends the `Database` class to implement the necessary SQL-formatting and resultset-fetching
diff --git a/newznab/data/source/database/adapter/pdo/Result.php b/nntmux/data/source/database/adapter/pdo/Result.php
similarity index 95%
rename from newznab/data/source/database/adapter/pdo/Result.php
rename to nntmux/data/source/database/adapter/pdo/Result.php
index 808e3983c..19a0dada6 100644
--- a/newznab/data/source/database/adapter/pdo/Result.php
+++ b/nntmux/data/source/database/adapter/pdo/Result.php
@@ -17,7 +17,7 @@
* @link .
* @author niel
*/
-namespace newznab\data\model\source\database\adapter\pdo;
+namespace nntmux\data\model\source\database\adapter\pdo;
use \PDO;
use \PDOStatement;
@@ -36,7 +36,7 @@ use \PDOException;
* @link http://php.net/manual/de/class.pdostatement.php The PDOStatement class.
* @link http://php.net/manual/de/class.iterator.php The Iterator interface.
*/
-class Result extends \newznab\data\source\Result
+class Result extends \nntmux\data\source\Result
{
public $named = false;
diff --git a/newznab/db/DB.php b/nntmux/db/DB.php
similarity index 99%
rename from newznab/db/DB.php
rename to nntmux/db/DB.php
index b4f2dbd23..54eafa632 100644
--- a/newznab/db/DB.php
+++ b/nntmux/db/DB.php
@@ -1,13 +1,13 @@
key++;
}
- if (count($this->return) > 0 && array_walk_recursive($this->return, '\newznab\utility\Utility::cp437toUTF')) {
+ if (count($this->return) > 0 && array_walk_recursive($this->return, '\nntmux\utility\Utility::cp437toUTF')) {
return json_encode($this->return, JSON_PRETTY_PRINT);
} else {
return false;
diff --git a/newznab/libraries/Cache.php b/nntmux/libraries/Cache.php
similarity index 99%
rename from newznab/libraries/Cache.php
rename to nntmux/libraries/Cache.php
index d1263e123..652e123a5 100644
--- a/newznab/libraries/Cache.php
+++ b/nntmux/libraries/Cache.php
@@ -1,12 +1,12 @@
doRandomSleep();
- $this->padb = new \newznab\db\populate\AniDB(
+ $this->padb = new \nntmux\db\populate\AniDB(
[
'Echo' => $this->echooutput,
'Settings' => $this->pdo
diff --git a/newznab/processing/post/ProcessAdditional.php b/nntmux/processing/post/ProcessAdditional.php
similarity index 99%
rename from newznab/processing/post/ProcessAdditional.php
rename to nntmux/processing/post/ProcessAdditional.php
index d8eba880c..7656c293d 100644
--- a/newznab/processing/post/ProcessAdditional.php
+++ b/nntmux/processing/post/ProcessAdditional.php
@@ -1,20 +1,20 @@
$admin->settings]);
diff --git a/www/admin/ajax_regex-list.php b/www/admin/ajax_regex-list.php
index 6b0d850b3..04809be1a 100644
--- a/www/admin/ajax_regex-list.php
+++ b/www/admin/ajax_regex-list.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\ReleaseRegex;
+use nntmux\ReleaseRegex;
// login check
$admin = new AdminPage;
diff --git a/www/admin/ajax_regex.php b/www/admin/ajax_regex.php
index 7fb14dd9f..ea6a4544a 100644
--- a/www/admin/ajax_regex.php
+++ b/www/admin/ajax_regex.php
@@ -2,8 +2,8 @@
require_once './config.php';
-use newznab\Regexes;
-use newznab\Binaries;
+use nntmux\Regexes;
+use nntmux\Binaries;
// Login Check
$admin = new AdminPage;
diff --git a/www/admin/ajax_sharing_settings.php b/www/admin/ajax_sharing_settings.php
index b42a0dbb3..0bd9f4475 100644
--- a/www/admin/ajax_sharing_settings.php
+++ b/www/admin/ajax_sharing_settings.php
@@ -3,9 +3,9 @@
require_once './config.php';
-use newznab\db\Settings;
-use newznab\Sharing;
-use newznab\ReleaseComments;
+use nntmux\db\Settings;
+use nntmux\Sharing;
+use nntmux\ReleaseComments;
// Login check.
$admin = new AdminPage;
diff --git a/www/admin/ajax_welcome_msg.php b/www/admin/ajax_welcome_msg.php
index 30daf73ba..d45a74be7 100644
--- a/www/admin/ajax_welcome_msg.php
+++ b/www/admin/ajax_welcome_msg.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Sites;
+use nntmux\Sites;
// login check
$admin = new AdminPage;
diff --git a/www/admin/anidb-delete.php b/www/admin/anidb-delete.php
index 8ead42bc0..ccfbb2253 100644
--- a/www/admin/anidb-delete.php
+++ b/www/admin/anidb-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\AniDB;
+use nntmux\AniDB;
$page = new AdminPage();
diff --git a/www/admin/anidb-edit.php b/www/admin/anidb-edit.php
index df147980d..700e77662 100644
--- a/www/admin/anidb-edit.php
+++ b/www/admin/anidb-edit.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/admin/anidb-list.php b/www/admin/anidb-list.php
index 1eff3742a..c9942eca7 100644
--- a/www/admin/anidb-list.php
+++ b/www/admin/anidb-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\AniDB;
+use nntmux\AniDB;
$page = new AdminPage();
diff --git a/www/admin/anidb-remove.php b/www/admin/anidb-remove.php
index 825012185..19bb49102 100644
--- a/www/admin/anidb-remove.php
+++ b/www/admin/anidb-remove.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/admin/binaryblacklist-edit.php b/www/admin/binaryblacklist-edit.php
index 4844ac05a..c2d8e39a1 100644
--- a/www/admin/binaryblacklist-edit.php
+++ b/www/admin/binaryblacklist-edit.php
@@ -1,8 +1,8 @@
$page->settings]);
diff --git a/www/admin/binaryblacklist-list.php b/www/admin/binaryblacklist-list.php
index 4a01036c5..e6ffafc1d 100644
--- a/www/admin/binaryblacklist-list.php
+++ b/www/admin/binaryblacklist-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Binaries;
+use nntmux\Binaries;
$page = new AdminPage();
diff --git a/www/admin/book-edit.php b/www/admin/book-edit.php
index bda4f2419..f28659413 100644
--- a/www/admin/book-edit.php
+++ b/www/admin/book-edit.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Books;
-use newznab\Genres;
+use nntmux\Books;
+use nntmux\Genres;
$page = new AdminPage();
$book = new Books();
diff --git a/www/admin/book-list.php b/www/admin/book-list.php
index e21a19249..a4cfc9392 100644
--- a/www/admin/book-list.php
+++ b/www/admin/book-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Books;
+use nntmux\Books;
$page = new AdminPage();
diff --git a/www/admin/category-edit.php b/www/admin/category-edit.php
index 4d98a2c69..37dfc8087 100644
--- a/www/admin/category-edit.php
+++ b/www/admin/category-edit.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Category;
+use nntmux\Category;
$page = new AdminPage();
$category = new Category();
diff --git a/www/admin/category-list.php b/www/admin/category-list.php
index a5ce1cfc6..5425e16d7 100644
--- a/www/admin/category-list.php
+++ b/www/admin/category-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Category;
+use nntmux\Category;
$page = new AdminPage();
diff --git a/www/admin/category_regexes-edit.php b/www/admin/category_regexes-edit.php
index c03168947..8503e310e 100644
--- a/www/admin/category_regexes-edit.php
+++ b/www/admin/category_regexes-edit.php
@@ -2,8 +2,8 @@
require_once './config.php';
-use newznab\Regexes;
-use newznab\Category;
+use nntmux\Regexes;
+use nntmux\Category;
$page = new AdminPage();
diff --git a/www/admin/category_regexes-list.php b/www/admin/category_regexes-list.php
index ee4767657..e1c9cb226 100644
--- a/www/admin/category_regexes-list.php
+++ b/www/admin/category_regexes-list.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Regexes;
+use nntmux\Regexes;
$page = new AdminPage();
$regexes = new Regexes(['Settings' => $page->settings, 'Table_Name' => 'category_regexes']);
diff --git a/www/admin/collection_regexes-edit.php b/www/admin/collection_regexes-edit.php
index fce434925..4accd15fa 100644
--- a/www/admin/collection_regexes-edit.php
+++ b/www/admin/collection_regexes-edit.php
@@ -2,8 +2,8 @@
require_once './config.php';
-use newznab\Regexes;
-use newznab\Category;
+use nntmux\Regexes;
+use nntmux\Category;
$page = new AdminPage();
$regexes = new Regexes(['Settings' => $page->settings, 'Table_Name' => 'collection_regexes']);
diff --git a/www/admin/collection_regexes-list.php b/www/admin/collection_regexes-list.php
index eb38eb51b..6cb4160bc 100644
--- a/www/admin/collection_regexes-list.php
+++ b/www/admin/collection_regexes-list.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Regexes;
+use nntmux\Regexes;
$page = new AdminPage();
$regexes = new Regexes(['Settings' => $page->settings, 'Table_Name' => 'collection_regexes']);
diff --git a/www/admin/collection_regexes-test.php b/www/admin/collection_regexes-test.php
index 712807313..1c03684f6 100644
--- a/www/admin/collection_regexes-test.php
+++ b/www/admin/collection_regexes-test.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Regexes;
+use nntmux\Regexes;
$page = new AdminPage();
diff --git a/www/admin/comments-delete.php b/www/admin/comments-delete.php
index a01c88967..8fb655a47 100644
--- a/www/admin/comments-delete.php
+++ b/www/admin/comments-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\ReleaseComments;
+use nntmux\ReleaseComments;
$page = new AdminPage();
diff --git a/www/admin/comments-list.php b/www/admin/comments-list.php
index 89f53bfca..6a7ea926b 100644
--- a/www/admin/comments-list.php
+++ b/www/admin/comments-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\ReleaseComments;
+use nntmux\ReleaseComments;
$page = new AdminPage();
diff --git a/www/admin/console-edit.php b/www/admin/console-edit.php
index 874143de6..bfa7de193 100644
--- a/www/admin/console-edit.php
+++ b/www/admin/console-edit.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Console;
-use newznab\Genres;
+use nntmux\Console;
+use nntmux\Genres;
$page = new AdminPage();
$console = new Console(['Settings' => $page->settings]);
diff --git a/www/admin/console-list.php b/www/admin/console-list.php
index ebd61cffb..058f13c37 100644
--- a/www/admin/console-list.php
+++ b/www/admin/console-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Console;
+use nntmux\Console;
$page = new AdminPage();
$con = new Console(['Settings' => $page->settings]);
diff --git a/www/admin/content-add.php b/www/admin/content-add.php
index 8911a9034..84b66eb88 100644
--- a/www/admin/content-add.php
+++ b/www/admin/content-add.php
@@ -2,9 +2,9 @@
require_once './config.php';
-use newznab\Contents;
-use newznab\Content;
-use newznab\Users;
+use nntmux\Contents;
+use nntmux\Content;
+use nntmux\Users;
$page = new AdminPage();
diff --git a/www/admin/content-delete.php b/www/admin/content-delete.php
index 07d9b8e75..bb21aca5c 100644
--- a/www/admin/content-delete.php
+++ b/www/admin/content-delete.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Contents;
+use nntmux\Contents;
$page = new AdminPage();
diff --git a/www/admin/content-list.php b/www/admin/content-list.php
index 7d31fefb6..66ba6fcac 100644
--- a/www/admin/content-list.php
+++ b/www/admin/content-list.php
@@ -2,7 +2,7 @@
require_once("config.php");
-use newznab\Contents;
+use nntmux\Contents;
$page = new AdminPage();
diff --git a/www/admin/failrel-list.php b/www/admin/failrel-list.php
index 00abc3794..4f9947ea5 100644
--- a/www/admin/failrel-list.php
+++ b/www/admin/failrel-list.php
@@ -3,7 +3,7 @@
require_once("config.php");
-use newznab\DnzbFailures;
+use nntmux\DnzbFailures;
$page = new AdminPage();
diff --git a/www/admin/forum-delete.php b/www/admin/forum-delete.php
index 38d80c3cb..f73ee306e 100644
--- a/www/admin/forum-delete.php
+++ b/www/admin/forum-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Forum;
+use nntmux\Forum;
$page = new AdminPage();
diff --git a/www/admin/game-edit.php b/www/admin/game-edit.php
index caa445ba3..78901e09e 100644
--- a/www/admin/game-edit.php
+++ b/www/admin/game-edit.php
@@ -2,8 +2,8 @@
require_once './config.php';
-use newznab\Games;
-use newznab\Genres;
+use nntmux\Games;
+use nntmux\Genres;
$page = new AdminPage();
$games = new Games(['Settings' => $page->settings]);
diff --git a/www/admin/game-list.php b/www/admin/game-list.php
index b7a531a56..924e6e1f1 100644
--- a/www/admin/game-list.php
+++ b/www/admin/game-list.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Games;
+use nntmux\Games;
$page = new AdminPage();
$game = new Games(['Settings' => $page->settings]);
diff --git a/www/admin/group-bulk.php b/www/admin/group-bulk.php
index 95bb5f9ce..c0f0cab66 100644
--- a/www/admin/group-bulk.php
+++ b/www/admin/group-bulk.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Groups;
+use nntmux\Groups;
$page = new AdminPage();
diff --git a/www/admin/group-edit.php b/www/admin/group-edit.php
index 97081ebe7..75a0c6134 100644
--- a/www/admin/group-edit.php
+++ b/www/admin/group-edit.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Groups;
+use nntmux\Groups;
$page = new AdminPage();
$groups = new Groups(['Settings' => $page->settings]);
diff --git a/www/admin/group-list-active.php b/www/admin/group-list-active.php
index 3eb3bcb11..84a47ab3e 100644
--- a/www/admin/group-list-active.php
+++ b/www/admin/group-list-active.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Groups;
+use nntmux\Groups;
$page = new AdminPage();
$groups = new Groups(['Settings' => $page->settings]);
diff --git a/www/admin/group-list-inactive.php b/www/admin/group-list-inactive.php
index 877f04b9c..4d7d774b8 100644
--- a/www/admin/group-list-inactive.php
+++ b/www/admin/group-list-inactive.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Groups;
+use nntmux\Groups;
$page = new AdminPage();
$groups = new Groups(['Settings' => $page->settings]);
diff --git a/www/admin/group-list.php b/www/admin/group-list.php
index 87ba06b4f..71c4c1f9e 100644
--- a/www/admin/group-list.php
+++ b/www/admin/group-list.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/admin/index.php b/www/admin/index.php
index 6ccdb4260..7adb08621 100644
--- a/www/admin/index.php
+++ b/www/admin/index.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\db\Settings;
+use nntmux\db\Settings;
$page = new AdminPage();
diff --git a/www/admin/menu-delete.php b/www/admin/menu-delete.php
index 1de3fd67e..19ce2d9d3 100644
--- a/www/admin/menu-delete.php
+++ b/www/admin/menu-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Menu;
+use nntmux\Menu;
$page = new AdminPage();
diff --git a/www/admin/menu-edit.php b/www/admin/menu-edit.php
index 14d9528b5..91c81242c 100644
--- a/www/admin/menu-edit.php
+++ b/www/admin/menu-edit.php
@@ -1,7 +1,7 @@
settings);
diff --git a/www/admin/menu-list.php b/www/admin/menu-list.php
index c506ca356..7a06934a4 100644
--- a/www/admin/menu-list.php
+++ b/www/admin/menu-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Menu;
+use nntmux\Menu;
$page = new AdminPage();
diff --git a/www/admin/movie-add.php b/www/admin/movie-add.php
index d0c1503e7..726486e99 100644
--- a/www/admin/movie-add.php
+++ b/www/admin/movie-add.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Movie;
+use nntmux\Movie;
$page = new AdminPage();
$movie = new Movie(['Settings' => $page->settings]);
diff --git a/www/admin/movie-edit.php b/www/admin/movie-edit.php
index c9952f681..07906dc8b 100644
--- a/www/admin/movie-edit.php
+++ b/www/admin/movie-edit.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Movie;
+use nntmux\Movie;
$page = new AdminPage();
$movie = new Movie();
diff --git a/www/admin/movie-list.php b/www/admin/movie-list.php
index df4222d9f..36e59785b 100644
--- a/www/admin/movie-list.php
+++ b/www/admin/movie-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Movie;
+use nntmux\Movie;
$page = new AdminPage();
$movie = new Movie(['Settings' => $page->settings]);
diff --git a/www/admin/music-edit.php b/www/admin/music-edit.php
index 0570f6a97..e1ef18df9 100644
--- a/www/admin/music-edit.php
+++ b/www/admin/music-edit.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Music;
-use newznab\Genres;
+use nntmux\Music;
+use nntmux\Genres;
$page = new AdminPage();
$music = new Music();
diff --git a/www/admin/music-list.php b/www/admin/music-list.php
index 0eb4bfca6..bf2e997a9 100644
--- a/www/admin/music-list.php
+++ b/www/admin/music-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Music;
+use nntmux\Music;
$page = new AdminPage();
diff --git a/www/admin/nzb-export.php b/www/admin/nzb-export.php
index 83eb50ddc..617e4b432 100644
--- a/www/admin/nzb-export.php
+++ b/www/admin/nzb-export.php
@@ -2,11 +2,11 @@
require_once './config.php';
-use newznab\Releases;
-use newznab\NZBExport;
+use nntmux\Releases;
+use nntmux\NZBExport;
-if (\newznab\utility\Utility::isCLI()) {
+if (\nntmux\utility\Utility::isCLI()) {
exit ('This script is only for exporting from the web, use the script in misc/testing' .
PHP_EOL);
}
diff --git a/www/admin/nzb-import.php b/www/admin/nzb-import.php
index 95837f8ac..c80026509 100644
--- a/www/admin/nzb-import.php
+++ b/www/admin/nzb-import.php
@@ -8,7 +8,7 @@ if (PHP_SAPI === 'cli') {
require_once './config.php';
-use newznab\NZBImport;
+use nntmux\NZBImport;
$page = new AdminPage();
diff --git a/www/admin/preview-list.php b/www/admin/preview-list.php
index 55b5dd4b7..d8525914f 100644
--- a/www/admin/preview-list.php
+++ b/www/admin/preview-list.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Releases;
-use newznab\Category;
+use nntmux\Releases;
+use nntmux\Category;
$page = new AdminPage();
$releases = new Releases();
diff --git a/www/admin/regex-edit.php b/www/admin/regex-edit.php
index 5662e6762..2433e06d0 100644
--- a/www/admin/regex-edit.php
+++ b/www/admin/regex-edit.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Category;
-use newznab\ReleaseRegex;
+use nntmux\Category;
+use nntmux\ReleaseRegex;
$page = new AdminPage();
$category = new Category();
diff --git a/www/admin/regex-list.php b/www/admin/regex-list.php
index 67ee3bb16..7150f8978 100644
--- a/www/admin/regex-list.php
+++ b/www/admin/regex-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\ReleaseRegex;
+use nntmux\ReleaseRegex;
$page = new AdminPage();
diff --git a/www/admin/regex-submit.php b/www/admin/regex-submit.php
index 6e0fd47b7..86acee887 100644
--- a/www/admin/regex-submit.php
+++ b/www/admin/regex-submit.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\ReleaseRegex;
+use nntmux\ReleaseRegex;
$page = new AdminPage();
$page->title = "Submit your regex expressions to newznab";
diff --git a/www/admin/regex-test.php b/www/admin/regex-test.php
index 9950c8c78..068fa7593 100644
--- a/www/admin/regex-test.php
+++ b/www/admin/regex-test.php
@@ -3,9 +3,9 @@
require_once './config.php';
-use newznab\ReleaseRegex;
-use newznab\Groups;
-use newznab\Category;
+use nntmux\ReleaseRegex;
+use nntmux\Groups;
+use nntmux\Category;
$page = new AdminPage();
diff --git a/www/admin/release-delete.php b/www/admin/release-delete.php
index a73dc113b..b5a99dc7c 100644
--- a/www/admin/release-delete.php
+++ b/www/admin/release-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Releases;
+use nntmux\Releases;
$page = new AdminPage();
diff --git a/www/admin/release-edit.php b/www/admin/release-edit.php
index 91133fbc0..a30fb73ef 100644
--- a/www/admin/release-edit.php
+++ b/www/admin/release-edit.php
@@ -1,8 +1,8 @@
$page->settings]);
diff --git a/www/admin/release-files.php b/www/admin/release-files.php
index e4f5b64d3..71775acf9 100644
--- a/www/admin/release-files.php
+++ b/www/admin/release-files.php
@@ -3,9 +3,9 @@
require_once './config.php';
-use newznab\Releases;
-use newznab\Users;
-use newznab\NZB;
+use nntmux\Releases;
+use nntmux\Users;
+use nntmux\NZB;
$page = new AdminPage;
$users = new Users;
diff --git a/www/admin/release-list.php b/www/admin/release-list.php
index 44bfc3de6..67906549d 100644
--- a/www/admin/release-list.php
+++ b/www/admin/release-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Releases;
+use nntmux\Releases;
$page = new AdminPage();
diff --git a/www/admin/release_naming_regexes-edit.php b/www/admin/release_naming_regexes-edit.php
index d6713165b..51d03b31c 100644
--- a/www/admin/release_naming_regexes-edit.php
+++ b/www/admin/release_naming_regexes-edit.php
@@ -2,8 +2,8 @@
require_once './config.php';
-use newznab\Regexes;
-use newznab\Category;
+use nntmux\Regexes;
+use nntmux\Category;
$page = new AdminPage();
$regexes = new Regexes(['Settings' => $page->settings, 'Table_Name' => 'release_naming_regexes']);
diff --git a/www/admin/release_naming_regexes-list.php b/www/admin/release_naming_regexes-list.php
index 9b7901319..dd1e32c75 100644
--- a/www/admin/release_naming_regexes-list.php
+++ b/www/admin/release_naming_regexes-list.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Regexes;
+use nntmux\Regexes;
$page = new AdminPage();
$regexes = new Regexes(['Settings' => $page->settings, 'Table_Name' => 'release_naming_regexes']);
diff --git a/www/admin/release_naming_regexes-test.php b/www/admin/release_naming_regexes-test.php
index f3c075122..b2b28efed 100644
--- a/www/admin/release_naming_regexes-test.php
+++ b/www/admin/release_naming_regexes-test.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Regexes;
+use nntmux\Regexes;
$page = new AdminPage();
diff --git a/www/admin/role-delete.php b/www/admin/role-delete.php
index bf568eb6b..85579e318 100644
--- a/www/admin/role-delete.php
+++ b/www/admin/role-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Users;
+use nntmux\Users;
$page = new AdminPage();
diff --git a/www/admin/role-edit.php b/www/admin/role-edit.php
index 986b5a04b..f53a5913d 100644
--- a/www/admin/role-edit.php
+++ b/www/admin/role-edit.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Users;
-use newznab\Category;
+use nntmux\Users;
+use nntmux\Category;
$page = new AdminPage();
$users = new Users();
diff --git a/www/admin/role-list.php b/www/admin/role-list.php
index 699310781..051e4cc57 100644
--- a/www/admin/role-list.php
+++ b/www/admin/role-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Users;
+use nntmux\Users;
$page = new AdminPage();
diff --git a/www/admin/sharing.php b/www/admin/sharing.php
index 2e1d55b67..ec9412be2 100644
--- a/www/admin/sharing.php
+++ b/www/admin/sharing.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/admin/show-list.php b/www/admin/show-list.php
index 96cc2b05a..833696611 100755
--- a/www/admin/show-list.php
+++ b/www/admin/show-list.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/admin/show-remove.php b/www/admin/show-remove.php
index 3f3e9c0cf..2325f62bd 100755
--- a/www/admin/show-remove.php
+++ b/www/admin/show-remove.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/admin/site-edit.php b/www/admin/site-edit.php
index 69bd40ba6..f5bc2148d 100644
--- a/www/admin/site-edit.php
+++ b/www/admin/site-edit.php
@@ -3,11 +3,11 @@
require_once './config.php';
-use newznab\Category;
-use newznab\SABnzbd;
-use newznab\db\Settings;
-use newznab\Sites;
-use newznab\utility\Utility;
+use nntmux\Category;
+use nntmux\SABnzbd;
+use nntmux\db\Settings;
+use nntmux\Sites;
+use nntmux\utility\Utility;
$category = new Category();
$page = new AdminPage();
diff --git a/www/admin/site-stats.php b/www/admin/site-stats.php
index 9e2306a09..e63dcbf20 100644
--- a/www/admin/site-stats.php
+++ b/www/admin/site-stats.php
@@ -3,8 +3,8 @@
require_once './config.php';
-use newznab\Users;
-use newznab\Releases;
+use nntmux\Users;
+use nntmux\Releases;
$page = new AdminPage();
$users = new Users();
diff --git a/www/admin/spotnab-delete.php b/www/admin/spotnab-delete.php
index 4f7fd43ce..abbcaebbf 100644
--- a/www/admin/spotnab-delete.php
+++ b/www/admin/spotnab-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\SpotNab;
+use nntmux\SpotNab;
$page = new AdminPage();
diff --git a/www/admin/spotnab-edit.php b/www/admin/spotnab-edit.php
index cf0f80a2f..0b09bb59f 100644
--- a/www/admin/spotnab-edit.php
+++ b/www/admin/spotnab-edit.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\SpotNab;
+use nntmux\SpotNab;
$page = new AdminPage();
$spotnab = new SpotNab();
diff --git a/www/admin/spotnab-list.php b/www/admin/spotnab-list.php
index c28659aad..d00121c21 100644
--- a/www/admin/spotnab-list.php
+++ b/www/admin/spotnab-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\SpotNab;
+use nntmux\SpotNab;
$page = new AdminPage();
diff --git a/www/admin/tmux-edit.php b/www/admin/tmux-edit.php
index 7dee39857..c77a6702e 100644
--- a/www/admin/tmux-edit.php
+++ b/www/admin/tmux-edit.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Tmux;
+use nntmux\Tmux;
$page = new AdminPage();
$tmux = new Tmux();
diff --git a/www/admin/user-delete.php b/www/admin/user-delete.php
index 0fdca90a7..bf8464884 100644
--- a/www/admin/user-delete.php
+++ b/www/admin/user-delete.php
@@ -2,7 +2,7 @@
require_once './config.php';
-use newznab\Users;
+use nntmux\Users;
$page = new AdminPage();
diff --git a/www/admin/user-edit.php b/www/admin/user-edit.php
index e6ec52999..59a718b32 100644
--- a/www/admin/user-edit.php
+++ b/www/admin/user-edit.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Users;
+use nntmux\Users;
$page = new AdminPage();
$users = new Users();
diff --git a/www/admin/user-list.php b/www/admin/user-list.php
index 8fe6eceb8..f767857de 100644
--- a/www/admin/user-list.php
+++ b/www/admin/user-list.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Users;
+use nntmux\Users;
$page = new AdminPage();
diff --git a/www/admin/view-logs.php b/www/admin/view-logs.php
index 7b481e2af..84e2fcc78 100644
--- a/www/admin/view-logs.php
+++ b/www/admin/view-logs.php
@@ -3,7 +3,7 @@
require_once './config.php';
-use newznab\Logger;
+use nntmux\Logger;
$page = new AdminPage();
$page->title = 'View Logs';
diff --git a/www/index.php b/www/index.php
index ec0263817..ceb7f59c5 100644
--- a/www/index.php
+++ b/www/index.php
@@ -1,7 +1,7 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/ajax_mymovies.php b/www/pages/ajax_mymovies.php
index dfea72a27..df93767f8 100644
--- a/www/pages/ajax_mymovies.php
+++ b/www/pages/ajax_mymovies.php
@@ -1,9 +1,9 @@
users->isLoggedIn()) {
diff --git a/www/pages/ajax_preinfo.php b/www/pages/ajax_preinfo.php
index 8ae477795..5d7b9790d 100644
--- a/www/pages/ajax_preinfo.php
+++ b/www/pages/ajax_preinfo.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/ajax_rarfilelist.php b/www/pages/ajax_rarfilelist.php
index f6f2fc6d0..d5bbdb1b4 100644
--- a/www/pages/ajax_rarfilelist.php
+++ b/www/pages/ajax_rarfilelist.php
@@ -1,5 +1,5 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/ajax_release-admin.php b/www/pages/ajax_release-admin.php
index b53b9ccf1..e02456e03 100644
--- a/www/pages/ajax_release-admin.php
+++ b/www/pages/ajax_release-admin.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/pages/ajax_resetusergrabs-admin.php b/www/pages/ajax_resetusergrabs-admin.php
index 4141ec3c5..31a761317 100644
--- a/www/pages/ajax_resetusergrabs-admin.php
+++ b/www/pages/ajax_resetusergrabs-admin.php
@@ -1,6 +1,6 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/anime.php b/www/pages/anime.php
index 29d9ee5c6..904858a65 100755
--- a/www/pages/anime.php
+++ b/www/pages/anime.php
@@ -1,8 +1,8 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/api.php b/www/pages/api.php
index 51456c3ac..eb8d5c5d3 100644
--- a/www/pages/api.php
+++ b/www/pages/api.php
@@ -1,10 +1,10 @@
users->isLoggedIn()) {
$page->show403();
}
-use newznab\Books;
-use newznab\Category;
-use newznab\DnzbFailures;
+use nntmux\Books;
+use nntmux\Category;
+use nntmux\DnzbFailures;
$book = new Books(['Settings' => $page->settings]);
$cat = new Category(['Settings' => $page->settings]);
diff --git a/www/pages/browse.php b/www/pages/browse.php
index 1bcabd1d9..d50e27c63 100644
--- a/www/pages/browse.php
+++ b/www/pages/browse.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/pages/browsegroup.php b/www/pages/browsegroup.php
index bd983b56e..bc4c4d798 100644
--- a/www/pages/browsegroup.php
+++ b/www/pages/browsegroup.php
@@ -3,7 +3,7 @@ if (!$page->users->isLoggedIn()) {
$page->show403();
}
-use newznab\Groups;
+use nntmux\Groups;
$groups = new Groups(['Settings' => $page->settings]);
diff --git a/www/pages/cart.php b/www/pages/cart.php
index 8312f8c80..998d39492 100644
--- a/www/pages/cart.php
+++ b/www/pages/cart.php
@@ -4,7 +4,7 @@ if (!$page->users->isLoggedIn()) {
$page->show403();
}
-use newznab\Releases;
+use nntmux\Releases;
if (isset($_GET["add"])) {
$releases = new Releases(['Settings' => $page->settings]);
diff --git a/www/pages/console.php b/www/pages/console.php
index f827e7bdf..8854d5ebc 100644
--- a/www/pages/console.php
+++ b/www/pages/console.php
@@ -4,10 +4,10 @@ if (!$page->users->isLoggedIn()) {
$page->show403();
}
-use newznab\Console;
-use newznab\Category;
-use newznab\Genres;
-use newznab\DnzbFailures;
+use nntmux\Console;
+use nntmux\Category;
+use nntmux\Genres;
+use nntmux\DnzbFailures;
$console = new Console(['Settings' => $page->settings]);
$cat = new Category(['Settings' => $page->settings]);
diff --git a/www/pages/consolemodal.php b/www/pages/consolemodal.php
index 2ae0fdfce..f220659f0 100644
--- a/www/pages/consolemodal.php
+++ b/www/pages/consolemodal.php
@@ -3,7 +3,7 @@
if (!$page->users->isLoggedIn())
$page->show403();
-use newznab\Console;
+use nntmux\Console;
if (isset($_GET["id"]) && ctype_digit($_GET["id"]))
{
diff --git a/www/pages/contact-us.php b/www/pages/contact-us.php
index 6da128d7f..47949c3fc 100644
--- a/www/pages/contact-us.php
+++ b/www/pages/contact-us.php
@@ -1,7 +1,7 @@
$page->settings]);
diff --git a/www/pages/details.php b/www/pages/details.php
index 0cc698ff8..b02cbf01e 100644
--- a/www/pages/details.php
+++ b/www/pages/details.php
@@ -1,20 +1,20 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/failed.php b/www/pages/failed.php
index 40eabd680..d777cff1d 100644
--- a/www/pages/failed.php
+++ b/www/pages/failed.php
@@ -1,7 +1,7 @@
users->isLoggedIn()) {
diff --git a/www/pages/filelist.php b/www/pages/filelist.php
index 58cbf94c5..41bb35006 100644
--- a/www/pages/filelist.php
+++ b/www/pages/filelist.php
@@ -1,7 +1,7 @@
users->isLoggedIn()) {
header('Location: ' . WWW_TOP . '/');
diff --git a/www/pages/forum.php b/www/pages/forum.php
index 7f5219e2c..8933050c9 100644
--- a/www/pages/forum.php
+++ b/www/pages/forum.php
@@ -1,5 +1,5 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/games.php b/www/pages/games.php
index 99b72881c..d2aae0fd2 100644
--- a/www/pages/games.php
+++ b/www/pages/games.php
@@ -1,9 +1,9 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/getnzb.php b/www/pages/getnzb.php
index cfa41b1ef..9890de163 100644
--- a/www/pages/getnzb.php
+++ b/www/pages/getnzb.php
@@ -1,9 +1,9 @@
smarty->assign(['error' => '', 'username' => '', 'rememberme' => '']);
diff --git a/www/pages/movie.php b/www/pages/movie.php
index 5afb47b2b..1bd13b7d2 100644
--- a/www/pages/movie.php
+++ b/www/pages/movie.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/movies.php b/www/pages/movies.php
index 45867816f..1b0d3f021 100644
--- a/www/pages/movies.php
+++ b/www/pages/movies.php
@@ -1,8 +1,8 @@
$page->settings]);
$cat = new Category(['Settings' => $page->settings]);
diff --git a/www/pages/movietrailer.php b/www/pages/movietrailer.php
index d7d44ae80..f58a1e37a 100644
--- a/www/pages/movietrailer.php
+++ b/www/pages/movietrailer.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/musicmodal.php b/www/pages/musicmodal.php
index 37a676ef3..3fefc2963 100644
--- a/www/pages/musicmodal.php
+++ b/www/pages/musicmodal.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/myshows.php b/www/pages/myshows.php
index 3e7834301..969bb44a2 100755
--- a/www/pages/myshows.php
+++ b/www/pages/myshows.php
@@ -1,9 +1,9 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/newposterwall.php b/www/pages/newposterwall.php
index f4271c9c3..065c23bfd 100644
--- a/www/pages/newposterwall.php
+++ b/www/pages/newposterwall.php
@@ -4,9 +4,9 @@ if (!$page->users->isLoggedIn()) {
$page->show403();
}
-use newznab\Releases;
-use newznab\Contents;
-use newznab\Category;
+use nntmux\Releases;
+use nntmux\Contents;
+use nntmux\Category;
$releases = new Releases(['Settings' => $page->settings]);
$contents = new Contents(['Settings' => $page->settings]);
diff --git a/www/pages/nfo.php b/www/pages/nfo.php
index a65ebdb66..ec8d6b1d3 100644
--- a/www/pages/nfo.php
+++ b/www/pages/nfo.php
@@ -1,7 +1,7 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/nzbvortex.php b/www/pages/nzbvortex.php
index 1ff4f3e5b..e89d73352 100644
--- a/www/pages/nzbvortex.php
+++ b/www/pages/nzbvortex.php
@@ -2,7 +2,7 @@
if (!$page->users->isLoggedIn())
$page->show403();
-use newznab\NZBVortex;
+use nntmux\NZBVortex;
try
{
diff --git a/www/pages/predb.php b/www/pages/predb.php
index eedaa8ab6..3e2c0f6a1 100644
--- a/www/pages/predb.php
+++ b/www/pages/predb.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/profile.php b/www/pages/profile.php
index 7fe1f9560..5bda0306e 100644
--- a/www/pages/profile.php
+++ b/www/pages/profile.php
@@ -1,8 +1,8 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/profileedit.php b/www/pages/profileedit.php
index d1356118e..930079455 100644
--- a/www/pages/profileedit.php
+++ b/www/pages/profileedit.php
@@ -1,10 +1,10 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/queuedata.php b/www/pages/queuedata.php
index 82fda0419..50f229f72 100644
--- a/www/pages/queuedata.php
+++ b/www/pages/queuedata.php
@@ -1,7 +1,7 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/register.php b/www/pages/register.php
index 6da0b1d8b..84e706af8 100644
--- a/www/pages/register.php
+++ b/www/pages/register.php
@@ -1,8 +1,8 @@
users->isLoggedIn()) {
diff --git a/www/pages/rss-info.php b/www/pages/rss-info.php
index 4ab98fb2c..e461de036 100755
--- a/www/pages/rss-info.php
+++ b/www/pages/rss-info.php
@@ -1,6 +1,6 @@
$page->settings]);
diff --git a/www/pages/rss.php b/www/pages/rss.php
index 3b3d51541..e2d5540b6 100755
--- a/www/pages/rss.php
+++ b/www/pages/rss.php
@@ -1,9 +1,9 @@
$page->settings]);
$rss = new RSS(['Settings' => $page->settings]);
diff --git a/www/pages/sabqueuedata.php b/www/pages/sabqueuedata.php
index c913f2896..66c1fae14 100644
--- a/www/pages/sabqueuedata.php
+++ b/www/pages/sabqueuedata.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/search.php b/www/pages/search.php
index 334e7696d..a8a55e250 100644
--- a/www/pages/search.php
+++ b/www/pages/search.php
@@ -1,9 +1,9 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/sendtocouch.php b/www/pages/sendtocouch.php
index 402576d87..9d1e24b45 100644
--- a/www/pages/sendtocouch.php
+++ b/www/pages/sendtocouch.php
@@ -1,6 +1,6 @@
users->isLoggedIn()){
$page->show403();
diff --git a/www/pages/sendtonzbget.php b/www/pages/sendtonzbget.php
index 190d482ad..2499d6aab 100644
--- a/www/pages/sendtonzbget.php
+++ b/www/pages/sendtonzbget.php
@@ -1,6 +1,6 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/sendtoqueue.php b/www/pages/sendtoqueue.php
index 280083d8a..28d059302 100644
--- a/www/pages/sendtoqueue.php
+++ b/www/pages/sendtoqueue.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/sendtosab.php b/www/pages/sendtosab.php
index d628f0f13..ac38a2d10 100644
--- a/www/pages/sendtosab.php
+++ b/www/pages/sendtosab.php
@@ -1,6 +1,6 @@
users->isLoggedIn())
$page->show403();
diff --git a/www/pages/series.php b/www/pages/series.php
index 26948fcc0..23ab22e0f 100644
--- a/www/pages/series.php
+++ b/www/pages/series.php
@@ -1,9 +1,9 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/sitemap.php b/www/pages/sitemap.php
index 6548ed1f5..d376ac456 100644
--- a/www/pages/sitemap.php
+++ b/www/pages/sitemap.php
@@ -1,7 +1,7 @@
smarty;
diff --git a/www/pages/smartyTV.php b/www/pages/smartyTV.php
index bf6847ddc..4b42eb553 100644
--- a/www/pages/smartyTV.php
+++ b/www/pages/smartyTV.php
@@ -18,9 +18,9 @@
* @author niel
* @copyright 2015 nZEDb
*/
-require_once '../../newznab/processing/tv/TV.php';
+require_once '../../nntmux/processing/tv/TV.php';
-use newznab\processing\tv\TV;
+use nntmux\processing\tv\TV;
class smartyTV extends TV
{
diff --git a/www/pages/upcoming.php b/www/pages/upcoming.php
index a0dd2d4d3..d3fcdc695 100644
--- a/www/pages/upcoming.php
+++ b/www/pages/upcoming.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/xxx.php b/www/pages/xxx.php
index fc146f9fd..012988b14 100644
--- a/www/pages/xxx.php
+++ b/www/pages/xxx.php
@@ -1,8 +1,8 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/pages/xxxmodal.php b/www/pages/xxxmodal.php
index f5044f204..f4f94d280 100644
--- a/www/pages/xxxmodal.php
+++ b/www/pages/xxxmodal.php
@@ -1,6 +1,6 @@
users->isLoggedIn()) {
$page->show403();
diff --git a/www/plugins/function.getcatval.php b/www/plugins/function.getcatval.php
index e8c57127b..04e88e39a 100755
--- a/www/plugins/function.getcatval.php
+++ b/www/plugins/function.getcatval.php
@@ -17,7 +17,7 @@
* @copyright 2016 nZEDb
*/
-use newznab\Category;
+use nntmux\Category;
/**
* Returns the value of the specified Category constant.
diff --git a/www/smarty.php b/www/smarty.php
index 6aebaeee4..b48acadab 100644
--- a/www/smarty.php
+++ b/www/smarty.php
@@ -22,7 +22,7 @@ require_once realpath(dirname(__DIR__) . DIRECTORY_SEPARATOR . 'constants.php');
require_once realpath(dirname(__DIR__) . DIRECTORY_SEPARATOR . 'autoloader.php');
//require_once 'autoloader.php';
-use newznab\config\Configure;
+use nntmux\config\Configure;
try {
$config = new Configure('smarty');
diff --git a/misc/testing/spotnab.php b/misc/testing/spotnab.php
index 6aa9a4c04..0c2632ab9 100644
--- a/misc/testing/spotnab.php
+++ b/misc/testing/spotnab.php
@@ -66,10 +66,10 @@
//
// server
// -/ code: This is taken from the users local database `site` table. It is
// the `code` the user configured their newznab server as.
//
// -/ title: This is also taken from the users local database `site` table. It
// is the the `title` the user configured their newznab server as.
//
// postdate_utc: This is the current time measured in the number of seconds since
// the Unix Epoch (January 1 1970 00:00:00 GMT). This represents
@@ -174,7 +174,7 @@ SHARING
require_once realpath(dirname(dirname(__DIR__)) . DIRECTORY_SEPARATOR . 'indexer.php');
-use newznab\SpotNab;
+use nntmux\SpotNab;
// Subject Lines will always be a hash key that helps scanning identify whether
// or not the contents are valid or not. the hash key contains is built
@@ -66,10 +66,10 @@
// server
// -/ code: This is taken from the users local database `site` table. It is
-// the `code` the user configured their newznab server as.
+// the `code` the user configured their nntmux server as.
//
// -/ title: This is also taken from the users local database `site` table. It
@@ -66,10 +66,10 @@
//
// -/ title: This is also taken from the users local database `site` table. It
-// is the the `title` the user configured their newznab server as.
+// is the the `title` the user configured their nntmux server as.
//
// postdate_utc: This is the current time measured in the number of seconds since
diff --git a/newznab/http/RSS.php b/nntmux/http/RSS.php
similarity index 97%
rename from newznab/http/RSS.php
rename to nntmux/http/RSS.php
index ce9fa5a49..63916a669 100755
--- a/newznab/http/RSS.php
+++ b/nntmux/http/RSS.php
@@ -1,16 +1,16 @@
returnApiRss();
break;
case 'rss':
- $this->namespace = 'nZEDb';
+ $this->namespace = 'nntmux';
return $this->returnApiRss();
break;
case 'reg':
@@ -260,7 +260,7 @@ class XML_Response
case 'newznab':
$url = 'http://www.newznab.com/DTD/2010/feeds/attributes/';
break;
- case 'nZEDb':
+ case 'nntmux':
default:
$url = $this->server['server']['url'] . 'rss-info/';
}
@@ -302,7 +302,7 @@ class XML_Response
$path = 'apihelp/';
$tag = 'API';
break;
- case 'nZEDb':
+ case 'nntmux':
default:
$path = 'rss-info/';
$tag = 'RSS';
@@ -314,13 +314,13 @@ class XML_Response
$this->xml->writeElement('language', 'en-gb');
$this->xml->writeElement('webMaster', $server['email'] . ' ' . $server['title']);
$this->xml->writeElement('category', $server['meta']);
- $this->xml->writeElement('generator', 'nZEDb');
+ $this->xml->writeElement('generator', 'nntmux');
$this->xml->writeElement('ttl', '10');
$this->xml->writeElement('docs', $this->server['server']['url'] . $path);
}
/**
* Adds nZEDB logo data to the XML
*/
protected function includeImage()
{
@@ -314,13 +314,13 @@ class XML_Response
}
/**
- * Adds nZEDB logo data to the XML
+ * Adds nntmux logo data to the XML
*/
protected function includeImage()